'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
var reactRouter = require('react-router');
var reactSwipeable = require('react-swipeable');
var SwipeableViews = _interopDefault(require('react-swipeable-views'));
var pathToRegexp = _interopDefault(require('path-to-regexp'));

var patternCache = {};
var cacheLimit = 10000;
var cacheCount = 0;

var compileGenerator = function compileGenerator(pattern) {
  var cacheKey = pattern;
  var cache = patternCache[cacheKey] || (patternCache[cacheKey] = {});

  if (cache[pattern]) return cache[pattern];

  var compiledGenerator = pathToRegexp.compile(pattern);

  if (cacheCount < cacheLimit) {
    cache[pattern] = compiledGenerator;
    cacheCount++;
  }

  return compiledGenerator;
};

/**
 * Public API for generating a URL pathname from a pattern and parameters.
 */
var generatePath = function generatePath() {
  var pattern = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '/';
  var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

  if (pattern === '/') {
    return pattern;
  }
  var generator = compileGenerator(pattern);
  return generator(params);
};

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var RouterCarousel = function RouterCarousel(props) {
  var _useState = React.useState([]),
      urls = _useState[0],
      changeUrls = _useState[1];

  var _useState2 = React.useState(0),
      slideIndex = _useState2[0],
      changeSlideIndex = _useState2[1];

  var _useState3 = React.useState(false),
      routeHas = _useState3[0],
      changeRouteHas = _useState3[1];

  var _useState4 = React.useState(false),
      swipeleft = _useState4[0],
      toggleSwipeLeft = _useState4[1];

  var _useState5 = React.useState(false),
      swiperight = _useState5[0],
      toggleSwipeRight = _useState5[1];

  var _useState6 = React.useState(false),
      swipeall = _useState6[0],
      toggleSwipeAll = _useState6[1];

  var children = props.children,
      index = props.index,
      location = props.location,
      history = props.history,
      sliderMode = props.sliderMode,
      swipeLeftClassName = props.swipeLeftClassName,
      swipeRightClassName = props.swipeRightClassName,
      fallbackRoute = props.fallbackRoute,
      routeMatch = props.match;


  var nullElement = React__default.createElement(
    React__default.Fragment,
    null,
    React__default.createElement("div", null)
  );
  var renderableRoutes = [];

  children.forEach(function () {
    renderableRoutes.push(nullElement);
  });

  if (!sliderMode) {
    var slide = React__default.Children.toArray(children).find(function (element) {
      return element && element.props && element.props.path === location.pathname;
    });
    renderableRoutes[slideIndex] = slide ? slide : nullElement;
  }
  var triggerOnChangeIndex = function triggerOnChangeIndex(location) {
    var children = props.children;

    React__default.Children.forEach(children, function (element, i) {
      var _element$props = element.props,
          pathProp = _element$props.path,
          exact = _element$props.exact,
          strict = _element$props.strict,
          from = _element$props.from;

      var path = pathProp || from;
      if (reactRouter.matchPath(location.pathname, { path: path, exact: exact, strict: strict })) {
        var _extends2;

        changeUrls(_extends({}, urls, (_extends2 = {}, _extends2[path] = location.pathname, _extends2)));
      }
    });
  };

  var createSlideUrl = function createSlideUrl(i) {
    var _React$Children$toArr = React__default.Children.toArray(children)[i].props,
        path = _React$Children$toArr.path,
        defaultParams = _React$Children$toArr.defaultParams;


    var url = void 0;
    if (path.includes(":")) {
      if (path in urls) {
        url = urls[path];
      } else {
        var _extends3;

        // Build url with defaults
        url = generatePath(path, defaultParams);
        changeUrls({ urls: _extends({}, urls, (_extends3 = {}, _extends3[path] = url, _extends3)) });
      }
    } else {
      url = path;
    }
    historyGoTo(url);
  };

  // Trigger the location change to the route path
  var handleIndexChange = function handleIndexChange(i) {
    if (!sliderMode) {
      createSlideUrl(i);
    }
    changeSlideIndex(i);
  };

  var historyGoTo = function historyGoTo(path) {
    var replace = props.replace,
        history = props.history;

    return replace ? history.replace(path) : history.push(path);
  };

  var slideLeft = function slideLeft(activate) {
    if (activate) {
      var prevSlide = slideIndex > 0 ? slideIndex - 1 : 0;
      changeSlideIndex(prevSlide);
      if (!sliderMode) {
        createSlideUrl(prevSlide);
      }
      return true;
    }
    return false;
  };

  var slideRight = function slideRight(activate) {
    if (activate) {
      var numberOfSlides = !sliderMode ? renderableRoutes.length - 1 : children.length - 1;
      var nextSlide = slideIndex < numberOfSlides ? slideIndex + 1 : numberOfSlides;
      changeSlideIndex(nextSlide);
      if (!sliderMode) {
        createSlideUrl(nextSlide);
      }
      return true;
    }
    return false;
  };

  var handlerLeftSwipe = reactSwipeable.useSwipeable({
    onSwipedRight: function onSwipedRight() {
      return slideLeft(swipeleft);
    },
    preventDefaultTouchmoveEvent: true,
    trackMouse: true
  });

  var handlerRightSwipe = reactSwipeable.useSwipeable({
    onSwipedLeft: function onSwipedLeft() {
      return slideRight(swiperight);
    },
    preventDefaultTouchmoveEvent: true,
    trackMouse: true
  });

  var updateLocationPath = function updateLocationPath() {
    var match = void 0;
    React__default.Children.forEach(children, function (element, i) {
      var _element$props2 = element.props,
          pathProp = _element$props2.path,
          exact = _element$props2.exact,
          strict = _element$props2.strict,
          from = _element$props2.from;

      var path = pathProp || from;

      match = reactRouter.matchPath(location.pathname, { path: path, exact: exact, strict: strict });
      if (match) {
        changeSlideIndex(i);
      }
    });
  };

  var checkerSwipeOnSlide = function checkerSwipeOnSlide() {
    var mode = !sliderMode ? renderableRoutes : children;
    if (mode && mode[slideIndex] && mode[slideIndex].props && mode[slideIndex].props.swipeleft) {
      toggleSwipeLeft(true);
    } else {
      toggleSwipeLeft(false);
    }
    if (mode && mode[slideIndex] && mode[slideIndex].props && mode[slideIndex].props.swiperight) {
      toggleSwipeRight(true);
    } else {
      toggleSwipeRight(false);
    }
    if (mode && mode[slideIndex] && mode[slideIndex].props && mode[slideIndex].props.swiperight || mode && mode[slideIndex] && mode[slideIndex].props && mode[slideIndex].props.swipeleft) {
      toggleSwipeAll(true);
    } else {
      toggleSwipeAll(false);
    }
  };

  var swipeLeftButton = React__default.createElement("section", _extends({}, handlerLeftSwipe, { className: swipeLeftClassName }));

  var swipeRightButton = React__default.createElement("section", _extends({}, handlerRightSwipe, { className: swipeRightClassName }));

  // Did mount
  React.useEffect(function () {
    if (!sliderMode) {
      var _history = props.history;

      triggerOnChangeIndex(_history.location);
      updateLocationPath();
    }
  }, []);

  React.useEffect(function () {
    if (!sliderMode) {
      updateLocationPath();
      changeRouteHas(renderableRoutes.some(function (route) {
        if (route && route.props && route.props.path && route.props.path.includes(":")) {
          var paramKey = Object.keys(route.props.defaultParams)[0];
          return route.props.path.replace(":" + paramKey, route.props.defaultParams[paramKey]) === location.pathname;
        }
        return route && route.props && route.props.path === location.pathname;
      }));
    }
  }, [location.pathname]);

  React.useEffect(function () {
    if (index && sliderMode) {
      var mode = !sliderMode ? renderableRoutes : children;
      var max = index >= mode.length ? mode.length : index;
      var result = max >= 1 ? max - 1 : 1;
      changeSlideIndex(result);
    }
  }, [index]);

  // Did update
  React.useEffect(function () {
    checkerSwipeOnSlide();
  });

  return React__default.createElement(
    React__default.Fragment,
    null,
    sliderMode && swipeleft && swipeLeftButton,
    swipeleft && routeHas && swipeLeftButton,
    !sliderMode && routeHas && React__default.createElement(
      SwipeableViews,
      {
        index: slideIndex,
        onChangeIndex: handleIndexChange,
        disabled: swipeall
      },
      renderableRoutes.map(function (element) {
        if (element && element.props) {
          var _ref = element && element.props,
              path = _ref.path,
              component = _ref.component,
              render = _ref.render,
              _children = _ref.children;

          var _props = { location: location, history: history };

          var match = reactRouter.matchPath(location.pathname, element && element.props);
          match = reactRouter.matchPath(generatePath(path, element && element.props && element.props.defaultParams), element && element.props);

          _props.match = match;
          _props.key = path;

          return component ? React__default.createElement(component, _props) : render ? render(_props) : _children;
        }
      })
    ),
    !routeHas && fallbackRoute || null,
    sliderMode && React__default.createElement(
      SwipeableViews,
      {
        index: slideIndex,
        onChangeIndex: handleIndexChange,
        disabled: swipeall
      },
      children
    ),
    swiperight && routeHas && swipeRightButton,
    sliderMode && swiperight && swipeRightButton
  );
};

var index = reactRouter.withRouter(RouterCarousel);

module.exports = index;
